#!/usr/bin/env python3
"""Main module for boto3auth."""

import boto3


def auth(resource, type='resource', region='us-east-1',
         account_id=False, role=False):
    """Return client/service for selected resource."""
    sess = boto3.Session()
    if account_id and role:
        sts = boto3.client('sts')
        creds = sts.assume_role(
            RoleArn=role,
            RoleSessionName='boto3auth',
        )
        sess = boto3.Session(
            aws_access_key_id=creds['Credentials']['AccessKeyId'],
            aws_secret_access_key=creds['Credentials']['SecretAccessKey'],
            aws_session_token=creds['Credentials']['SessionToken']
        )
    if type == 'client':
        return sess.client(resource, region_name=region)
    return sess.resource(resource, region_name=region)



#!/usr/bin/env python3
"""Setup file for boto3-service."""

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="boto3auth",
    version="1.0.0",
    author="Matthew Salazar",
    author_email="m@tthewsalazar.com",
    description="Simple wrapper for starting Boto3 clients/resources.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/mtslzr/boto3auth",
    packages=setuptools.find_packages(),
    install_requires=[
        'boto3'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
